Enum bigml::ErrorKind
[−]
pub enum ErrorKind {
Msg(String),
Io(Error),
Json(Error),
CouldNotAccessUrl(Url),
CouldNotGetOutput(String),
CouldNotReadFile(PathBuf),
OutputNotAvailable,
UnexpectedHttpStatus(StatusCode, String),
WrongResourceType(&'static str, String),
}The kind of an error.
Variants
Msg(String)A convenient variant for String.
Io(Error)Json(Error)CouldNotAccessUrl(Url)We could not access the specified URL.
CouldNotGetOutput(String)We could not get an output value from a WhizzML script.
CouldNotReadFile(PathBuf)We failed to read the specified file.
OutputNotAvailableWe could not access an output value of a WhizzML script.
UnexpectedHttpStatus(StatusCode, String)We received an unexpected HTTP status code.
WrongResourceType(&'static str, String)We found a type mismatch deserializing a BigML resource ID.
Methods
impl ErrorKind
fn description(&self) -> &str
A string describing the error kind.