macro_rules! try_wait {
($e:expr) => { ... };
}Expand description
Try e, and if it fails, allow our wait function to be retried for
temporary errors only.
macro_rules! try_wait {
($e:expr) => { ... };
}Try e, and if it fails, allow our wait function to be retried for
temporary errors only.