Module wait

Module wait 

Utilities for waiting, timeouts and error retries.

Structs

WaitOptions
Options controlling how long we wait and what makes us give up. This uses a “builder” pattern, so you can write:

Enums

BackoffType
How should we back off if we fail?
WaitStatus
Return this value from a wait callback.

Functions

wait
Call f repeatedly, wait for it to return WaitStatus::Finished, an error, or a timeout. Honors WaitOptions.